@@ -46,13 +46,13 @@ public:
 
 void AddTransportDialogNGPrivate::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QStringLiteral("AddTransportDialog"));
+    KConfigGroup group(KSharedConfig::openStateConfig(), u"AddTransportDialog"_s);
     group.writeEntry("Size", q->size());
 }
 
 void AddTransportDialogNGPrivate::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QStringLiteral("AddTransportDialog"));
+    KConfigGroup group(KSharedConfig::openStateConfig(), u"AddTransportDialog"_s);
     const QSize sizeDialog = group.readEntry("Size", QSize(300, TransportManager::self()->types().size() > 1 ? 300 : 160));
     if (sizeDialog.isValid()) {
         q->resize(sizeDialog);
